@@ -2,29 +2,36 @@ import asyncio
 import typing
 from datetime import datetime
 from typing import Dict
+
+from .shared import get_bot
 from .irc import Irc
 from .config import cfg
 from .permission import perms
-from twitchbot.api.chatters import Chatters
+from .api.chatters import Chatters
 from .api import StreamInfoApi
+from .util import get_user_followers, get_headers
+from .data import UserFollowers
 
 if typing.TYPE_CHECKING:
     from .bots import BaseBot
 
 
 class Channel:
-    def __init__(self, name, irc, bot=None, register_globally=True):
+    def __init__(self, name, irc, register_globally=True):
         self.irc: Irc = irc
         self.name: str = name
         self.chatters: Chatters = Chatters(self.name)
-        self.is_mod = False
-        self.stats = StreamInfoApi(cfg.client_id, self.name)
-        self.bot: 'BaseBot' = bot
+        self.is_mod: bool = False
+        self.stats: StreamInfoApi = StreamInfoApi(cfg.client_id, self.name)
+        self.bot: 'BaseBot' = get_bot()
 
         if register_globally:
             channels[self.name.lower()] = self
             perms.load_permissions(name)
 
+    async def followers(self) -> UserFollowers:
+        return await get_user_followers(self.name, get_headers())
+
     @property
     def live(self):
         return self.stats.started_at != datetime.min
@@ -60,6 +67,13 @@ class Channel:
         """
         await self.send_command(f'timeout {user} {duration}')
 
+    async def purge(self, user: str):
+        """
+        purges a user in the room (removes their messages via a 1 second timeout)
+        :param user: user to purge
+        """
+        await self.timeout(user, 1)
+
     async def color(self, color: str):
         """sets the bots chat color"""
         await self.send_command(f'color {color}')
