@@ -3,9 +3,12 @@ import json
 from pathlib import Path
 from .gui import show_auth_gui
 
-__all__ = ('cfg', 'Config')
+__all__ = ('cfg', 'Config', 'mysql_cfg', 'CONFIG_FOLDER')
+
+CONFIG_FOLDER = Path('configs')
 
 
+# noinspection PyTypeChecker
 class Config:
     def __init__(self, file_path: Path, **defaults):
         self.file_path = file_path
@@ -88,8 +91,9 @@ class Config:
 
 DEFAULT_OAUTH = 'oauth:'
 DEFAULT_NICK = 'nick'
+
 cfg = Config(
-    file_path=Path('configs', 'config.json'),
+    file_path=CONFIG_FOLDER / 'config.json',
     nick=DEFAULT_NICK,
     oauth=DEFAULT_OAUTH,
     client_id='CLIENT_ID',
@@ -106,8 +110,37 @@ cfg = Config(
     disable_whispers=False,
 )
 
-if cfg.nick == DEFAULT_NICK or cfg.oauth == DEFAULT_OAUTH:
-    print('please enter your twitch auth info the the GUI that will pop-up shortly')
-    auth = show_auth_gui()
-    cfg['nick'] = auth.username
-    cfg['oauth'] = auth.oauth
+mysql_cfg = Config(
+    CONFIG_FOLDER / 'mysql.json',
+    enabled=False,
+    address='localhost',
+    port='3306',
+    username='root',
+    password='password',
+    database='twitchbot',
+)
+
+
+def init_config():
+    if cfg.nick == DEFAULT_NICK or cfg.oauth == DEFAULT_OAUTH:
+        print('please enter your twitch auth info the the GUI that will pop-up shortly')
+        auth = show_auth_gui()
+        cfg['nick'] = auth.username
+        cfg['oauth'] = auth.oauth
+    if 'oauth:' not in cfg['oauth']:
+        print('oauth must start with `oauth:` and be followed by the token itself, ex: oauth:exampletoken12')
+        input('press enter to exit...')
+        exit()
+    if len(cfg['oauth']) <= 10:
+        print('oauth is too short, must be `oauth:` followed by the token itself, ex: oauth:exampletoken12')
+        input('press enter to exit...')
+        exit()
+    # this is to fix the edge case where the user entered enters cased names / channel names
+    # without this, the twitch API returns weird responses that are not easy to figure out why it is doing it
+    cfg['nick'] = cfg['nick'].lower()
+    cfg['owner'] = cfg['owner'].lower()
+    cfg['channels'] = [chan.lower() for chan in cfg['channels']]
+    cfg.save()
+
+
+init_config()
